==> spellathon-5.34.tar.gz: spellathon-5.34/src/logic/score.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _SCORE_H
#define _SCORE_H

namespace Spellathon 
{
	class Score
	{
	public:
		explicit Score(int nw, int nt, int h, int t)
		{
			double s = 100;
	
			/* time penalty */
			if ((nt <= 5 && t/nt > 10)  ||
			    (nt <= 10 && t/nt > 15) ||
			    (nt <= 20 && t/nt > 20) ||
			     t/nt > 30)
				s -= 10;
	
			/* hint penalty */
			switch (h) {
			case 1:
				s -= 10;
				break;
			case 2:
				s -= 25;
				break;
			}
	
			/* fraction of total words correct */
			s *= nw/(double)nt;
			score_ = (int)s;
	
			if (score_ > 90) {
				rating_ = Ratings[5];
				rating_ += '!';
				return;
			}
			if (score_ > 80) {
				rating_ = Ratings[4];
				rating_ += '!';
				return;
			}
			if (score_ > 70) {
				rating_ = Ratings[3];
				return;
			}
			if (score_ >= 55) {
				rating_ = Ratings[2];
				return;
			}
			if (score_ > 30) {
				rating_ = Ratings[1];
				return;
			}
			rating_ = Ratings[0];
		}

	int score() const { return score_; }
	string rating() const { return rating_; }

	private:
		int	score_;
		string	rating_;
	};
}

#endif /* _SCORE_H */

==> spellathon-5.40.tar.gz: spellathon-5.40/src/logic/score.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _SCORE_H
#define _SCORE_H

namespace Spellathon 
{
	class Score
	{
	public:
		explicit Score(int nw, int nt, int h, int t, bool entered7)
		{
			double s = 100;
	
			/* time penalty */
			if ((nt <= 5 && t/nt > 10)  ||
			    (nt <= 10 && t/nt > 15) ||
			    (nt <= 20 && t/nt > 20) ||
			     t/nt > 30)
				s -= TimePenalty;
	
			/* hint penalty */
			switch (h) {
			case 1:
				s -= HintPenalty[0];
				break;
			case 2:
				s -= HintPenalty[1];
				break;
			}
	
			if (!entered7)
				s -= No7Penalty;

			/* fraction of total words correct */
			s *= nw/(double)nt;
			score_ = (int)s;
	
			if (score_ >= Scores[3]) {
				rating_ = Ratings[3];
				rating_ += '!';
				return;
			}
			if (score_ >= Scores[2]) {
				rating_ = Ratings[2];
				return;
			}
			if (score_ > Scores[1]) {
				rating_ = Ratings[1];
				return;
			}
			rating_ = Ratings[0];
		}

	int score() const { return score_; }
	string rating() const { return rating_; }

	private:
		int	score_;
		string	rating_;
	};
}

#endif /* _SCORE_H */
